@@ -1,5 +1,5 @@
 
-from analytics.loggers.file import StreamLogger, FileLogger, RotatingFileLogger
+from scuttle.loggers.file import StreamLogger, FileLogger, RotatingFileLogger
 
 class TestLogger(object):
     def write(self, event, timestamp, attributes):
